library(DESeq2)
library(ggplot2)
library(plyr)

raw_counts <- read.table("./GSE65189_SA11-counts_raw.txt", sep="\t", row.names=1, header=TRUE)
col_data <- read.table("./GSE65189_SA11-coldata.txt", sep="\t", row.names=1, header=TRUE)
annotations <- read.table("./gene_annotations.txt", sep="\t", row.names=1, header=TRUE)

dds <- DESeqDataSetFromMatrix(countData = raw_counts,
                              colData = col_data,
                              design = ~ condition)
### create DESeq object from raw counts
dds <- DESeq(dds)

### create DESeq results object
res <- results(dds)
resGA <- results(dds, lfcThreshold=1, altHypothesis="greaterAbs")

### Write out a tab delimited table of the results
write.table(resGA, 'DEseq2_output_SA11_greaterAbs', row.names=TRUE, quote=FALSE, sep='\t')
write.table(res, 'DEseq2_output_SA11', row.names=TRUE, quote=FALSE, sep='\t')

### Create matrix of variables of interest for creating MA-plots
gene = rownames(res)
baseMean = as.numeric(res$baseMean)
foldchange = as.numeric(-res$log2FoldChange)
pval = as.numeric(res$padj)
pthreshold = as.character(cut(pval, breaks = c(0,0.05,1), labels =c("significant", "not_significant")))
foldthreshold = as.character(cut(foldchange, breaks = c(-10,-1,1,10 ), labels =c("significant", "not_significant", "significant")))
ann = annotations$Description
resMAT <- as.data.frame(cbind(baseMean, foldchange, pval))
resMAT <- cbind(resMAT, gene, pthreshold, foldthreshold, ann)


test <- subset(resMAT, foldthreshold=="significant" & pthreshold=="significant")
combined_signif <- test$foldthreshold
test$combined_signif <- combined_signif
test1 <- test[,c("gene", "combined_signif")]

total <- merge(resMAT, test1,by="gene",all=TRUE)

### ggplot implementation of MA-plot
ggplot(total, aes(x=baseMean, y=foldchange)) + 
  geom_point(aes(color = combined_signif)) + 
  geom_point(subset = .(ann == 'Sid3'), color = '#F8766D', size = 5) + 
  geom_point(subset = .(ann == 'Sid2'), color = '#CD9600', size = 5) + 
  geom_point(subset = .(ann == 'Sid1'), color = '#7CAE00', size = 5) + 
  geom_point(subset = .(ann == 'Heme'), color = '#00BE67', size = 5) + 
  geom_point(subset = .(ann == 'Fe3+ SBP3'), color = '#00BFC4', size = 5) + 
  geom_point(subset = .(ann == 'Fe3+ SBP2'), color = '#00A9FF', size = 5) + 
  geom_point(subset = .(ann == 'Fe3+ SBP1'), color = '#C77CFF', size = 5) + 
  geom_point(subset = .(ann == 'Other putative Fe uptake'), color = '#FF61CC', size = 5) + 
  scale_x_log10() + 
  labs(title = "MA-plot S sp. SA11 + PC9", x = "mean expression", y = "Log2 Fold Change", colour = "Pvalue FDR") 
 

### Default DESeq2 function for creating MA plots
pma <- plotMA(res, main="DESeq2", ylim=c(-8,6))


### For making plots for individual genes
plotCounts(dds, gene=c("SA11v2_00762"), intgroup="condition", returnData=TRUE)

ggplot(d, aes(x=condition, y=count)) +
  geom_point(size=4, position=position_jitter(w=0.1,h=0)) +
  theme_bw()


